@@ -1,4 +1,17 @@
 class ElviaException(Exception):
+    def __init__(self, message):
+        self.message = message
+
+
+class ElviaClientException(ElviaException):
+    pass
+
+
+class MissingCredentialsException(ElviaException):
+    pass
+
+
+class ElviaServerException(ElviaException):
     def __init__(self, message, status_code, headers, body):
         self.message = message
         self.status_code = status_code
@@ -9,13 +22,13 @@ class ElviaException(Exception):
         return self.message + " " + str(self.status_code) + " " + self.body
 
 
-class AuthError(ElviaException):
+class AuthError(ElviaServerException):
     pass
 
 
-class InvalidRequestBody(ElviaException):
+class InvalidRequestBody(ElviaServerException):
     pass
 
 
-class UnexpectedError(ElviaException):
+class UnexpectedError(ElviaServerException):
     pass
