@@ -4,13 +4,6 @@ from typing import List
 from elvia.types.common import CustomerContract
 
 
-class MeterValueParams(TypedDict):
-    start_time: str
-    end_time: str
-    metering_point_ids: List[str]
-    include_production: bool
-
-
 class MeterValueTimeSeries(TypedDict):
     startTime: str
     endTime: str
